#define HAVE_SYS_TYPES_H 1
#define HAVE_UNISTD_H 1
#define PQXX_HAVE_COUNT_IF 1
/* #undef PQXX_HAVE_LOCALE */
#define PQXX_HAVE_SLEEP 1
/* #undef PQXX_HAVE_STRING_CLEAR */
#define PQXX_HAVE_SYS_SELECT_H 1
#define PQXX_SELECT_ACCEPTS_NULL 1
